macro_rules! log_error {
($fmt:literal, $($arg:expr),*) => { ... };
}Expand description
Logs an error at ERROR level for critical failures that may need attention.
macro_rules! log_error {
($fmt:literal, $($arg:expr),*) => { ... };
}Logs an error at ERROR level for critical failures that may need attention.